/*******************************************************************************
 * Copyright (c) 2011 Michael Ruflin, Andr Locher, Claudia von Bastian.
 * 
 * This file is part of Tatool.
 * 
 * Tatool is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published 
 * by the Free Software Foundation, either version 3 of the License, or 
 * (at your option) any later version.
 * 
 * Tatool is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Tatool. If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/
package ch.tatool.core.module.statistics;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Font;
import java.awt.geom.Ellipse2D;
import java.awt.geom.Rectangle2D;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Set;

import javax.swing.JFrame;
import javax.swing.JPanel;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import ch.tatool.core.data.Level;
import ch.tatool.core.data.Misc;
import ch.tatool.core.data.Points;
import ch.tatool.core.element.handler.score.PointsAndLevelUtils;
import ch.tatool.data.DataService;
import ch.tatool.data.Module;
import ch.tatool.data.ModuleSession;
import de.erichseifert.gral.Legend;
import de.erichseifert.gral.Location;
import de.erichseifert.gral.PlotArea;
import de.erichseifert.gral.data.Column;
import de.erichseifert.gral.data.DataSeries;
import de.erichseifert.gral.data.DataTable;
import de.erichseifert.gral.data.statistics.Statistics;
import de.erichseifert.gral.plots.BarPlot;
import de.erichseifert.gral.plots.Plot;
import de.erichseifert.gral.plots.XYPlot;
import de.erichseifert.gral.plots.axes.Axis;
import de.erichseifert.gral.plots.axes.AxisRenderer;
import de.erichseifert.gral.plots.axes.LinearRenderer2D;
import de.erichseifert.gral.plots.lines.DefaultLineRenderer2D;
import de.erichseifert.gral.plots.lines.LineRenderer;
import de.erichseifert.gral.plots.points.DefaultPointRenderer;
import de.erichseifert.gral.plots.points.PointRenderer;
import de.erichseifert.gral.ui.DrawablePanel;
import de.erichseifert.gral.util.Insets2D;

/**
 * Default chart based module statistics panel.
 * 
 * Displays the session index on the x-axis and the performance on the y-axis.
 * 
 * @author Michael Ruflin, Andre Locher
 */
public class DefaultChartStatistics extends AbstractChartStatistics {

	Logger logger = LoggerFactory.getLogger(DefaultChartStatistics.class);
	private static final long serialVersionUID = 7404444913392296771L;
	
	private ArrayList<DataTable> levelDatasets;
	private ArrayList<DataTable> performanceDatasets;
	
	private DataTable levelDataset;
	private DataTable performanceDataset;
	
	private XYPlot plot;

	public DefaultChartStatistics() {
		initializeChartObjects();
	}

	private void initializeChartObjects() {

	}

	protected JPanel createChart(DataService dataService,
			Module module) {

		plot = new XYPlot();
		createDataSets(dataService, module);
		
		DataSeries performanceSeries = new DataSeries("% Korrekt", performanceDataset, 0, 1);
		DataSeries levelSeries = new DataSeries("Level", levelDataset, 0, 1);
		
		JPanel plotPanel = stylePlot("Statistik", plot, performanceSeries, levelSeries);
		return plotPanel;
	}

	private JPanel stylePlot(String title, XYPlot plot, DataSeries series1, DataSeries series2) {
		// Style plot and plot area
        plot.setInsets(new Insets2D.Double(10.0, 80.0, 120.0, 80.0));
        plot.setSetting(BarPlot.TITLE, title);
        plot.getPlotArea().setSetting(PlotArea.COLOR, new Color(255, 255, 255));
        
        Column colLevel = series2.getColumn(1);
        Axis y2 = new Axis(0, colLevel.getStatistics(Statistics.MAX) + 1);
        plot.setAxis(XYPlot.AXIS_Y2, y2);
        LinearRenderer2D rend = new LinearRenderer2D();
        rend.setSetting(AxisRenderer.INTERSECTION, Double.MAX_VALUE);
        rend.setSetting(AxisRenderer.TICKS_MINOR, false);
        rend.setSetting(AxisRenderer.LABEL_ROTATION, 90);
        rend.setSetting(AxisRenderer.LABEL_FONT, Font.decode("Arial-15"));
        plot.setAxisRenderer(XYPlot.AXIS_Y2, rend);

        plot.getAxisRenderer(XYPlot.AXIS_X).setSetting(AxisRenderer.LABEL, "Session");
        plot.getAxisRenderer(XYPlot.AXIS_X).setSetting(AxisRenderer.LABEL_FONT, Font.decode("Arial-15"));
        plot.getAxisRenderer(XYPlot.AXIS_X).setSetting(AxisRenderer.TICKS_FONT, Font.decode("Arial-14"));
        plot.getAxisRenderer(XYPlot.AXIS_Y).setSetting(AxisRenderer.LABEL, "% Korrekt");
        plot.getAxisRenderer(XYPlot.AXIS_Y).setSetting(AxisRenderer.LABEL_FONT, Font.decode("Arial-15"));
        plot.getAxisRenderer(XYPlot.AXIS_Y).setSetting(AxisRenderer.TICKS_FONT, Font.decode("Arial-14"));
        plot.getAxisRenderer(XYPlot.AXIS_Y2).setSetting(AxisRenderer.LABEL, "Level");
        plot.getAxisRenderer(XYPlot.AXIS_X).setSetting(AxisRenderer.TICKS_SPACING, 1.0);
        plot.getAxisRenderer(XYPlot.AXIS_X).setSetting(AxisRenderer.TICKS_MINOR, false);
        plot.getAxisRenderer(XYPlot.AXIS_Y).setSetting(AxisRenderer.TICKS_SPACING, 10.0);
        plot.getAxisRenderer(XYPlot.AXIS_Y2).setSetting(AxisRenderer.TICKS_SPACING, 1.0);
        
        
        Column colSessions = series1.getColumn(0);
        plot.getAxis(XYPlot.AXIS_X).setRange(1,colSessions.getStatistics(Statistics.MAX) + 1);
        plot.getAxis(XYPlot.AXIS_Y).setRange(0, 100.9);
 
        DrawablePanel panel = new DrawablePanel(plot);
        Color colorRed = new Color(204, 51, 0);
        Color colorBlack = new Color(0, 0, 0);

        LineRenderer linesPerform = new DefaultLineRenderer2D();
        linesPerform.setSetting(LineRenderer.COLOR, colorRed);
        
        plot.add(series1);
        plot.add(series2);
        
        LineRenderer linesLevel = new DefaultLineRenderer2D();
        linesLevel.setSetting(LineRenderer.COLOR, colorBlack);
        plot.setLineRenderer(series1, linesPerform);
        plot.setLineRenderer(series2, linesLevel);
        
        PointRenderer pointsPerform = new DefaultPointRenderer();
        pointsPerform.setSetting(PointRenderer.COLOR, colorRed);
        pointsPerform.setSetting(PointRenderer.SHAPE, new Ellipse2D.Double(-4.0, -4.0, 8.0, 8.0));
        
        PointRenderer pointsLevel = new DefaultPointRenderer();
        pointsLevel.setSetting(PointRenderer.COLOR, colorBlack);
        pointsLevel.setSetting(PointRenderer.SHAPE, new Rectangle2D.Double(-4.0, -4.0, 8.0, 8.0));
        
        plot.setPointRenderer(series1, pointsPerform);
        plot.setPointRenderer(series2, pointsLevel);
        plot.setMapping(series2, XYPlot.AXIS_X, XYPlot.AXIS_Y2);
        plot.setSetting(XYPlot.LEGEND, true);
        plot.setSetting(XYPlot.LEGEND_LOCATION, Location.SOUTH_EAST);
        plot.setSetting(XYPlot.LEGEND_MARGIN, new Insets2D.Double(0, 0 ,-120 , 0));
        plot.getLegend().setSetting(Legend.FONT, Font.decode("Arial-15"));
        
        return panel;
		
	}

	/**
	 * Updates the chart display with a new chart displaying the current
	 * module state.
	 */
	private void createDataSets(DataService dataService,
			Module module) {

        // find all PointsAndLevelHandler, each one gets a line in the graph
        Set<String> handlerIds = PointsAndLevelUtils.getRegisteredPointsAndLevelHandlers(module);
        if (handlerIds.size() < 1) {
        	return;
        }
        
		levelDatasets = new ArrayList<DataTable>();
		performanceDatasets = new ArrayList<DataTable>();

        for (String handlerId : handlerIds) {
        	String description = Misc.getDescriptionProperty().getValue(module, handlerId, handlerId);

    		levelDataset = new DataTable(Integer.class, Integer.class);
    		performanceDataset = new DataTable(Integer.class, Integer.class);
    		
			// loop through all sessions
			List<ModuleSession> sessions = dataService
					.getSessions(module);

			// find the maximum level for the given handler
			int maxLevel = 1;
			for (ModuleSession session : sessions) {
				int tmp = Level.getLevelProperty().getValue(session, handlerId, 0);
				maxLevel = (maxLevel < tmp) ? tmp : maxLevel;
			}

			// add a zero element
			performanceDataset.add(0, 0);
			levelDataset.add(1, 0);
			
			// go through each session
			double lastScore = 0;
			int sessionID = 0;
			for (int i = 0; i < sessions.size(); i++) {
				ModuleSession currSession = sessions.get(i);
				// only create a data point if session wasn't aborted
				if (currSession.getEndTime() == null) {
					continue;
				}
				
				// fetch session data
				int level = Level.getLevelProperty().getValue(currSession, handlerId, 1);
				int score = Points.getTotalPointsProperty().getValue(currSession, handlerId, 0);
				int maxScore = Points.getTotalMaxPointsProperty().getValue(currSession, handlerId, 0);
				int finalScore = 0;
				sessionID++;

				// calculate the final score
				if (maxScore == 0) {
					finalScore = (int) lastScore;
				} else {
					finalScore = (int)(((double) score / (double) maxScore) * 100);
				}
				lastScore = (finalScore > 0) ? finalScore : lastScore;

				performanceDataset.add(sessionID, finalScore);
				levelDataset.add(sessionID, level);
			}
			
			performanceDatasets.add(performanceDataset);
			levelDatasets.add(levelDataset);
		}

	}

	public static void main(String arg[]) {
		
	}

	public void setModule(Module module) {
		// TODO Auto-generated method stub
		
	}

	public void updateModuleInfo(Module module, Date lastExportDate) {
		// TODO Auto-generated method stub
		
	}
}
